# -*- coding: utf-8 -*-
from django import dispatch

monitor_up_check = dispatch.Signal()
